// EdObjective.h: interface for the EdObjective class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_EDOBJECTIVE_H__ED62766D_CF98_40E3_8DAF_C3C7563447A8__INCLUDED_)
#define AFX_EDOBJECTIVE_H__ED62766D_CF98_40E3_8DAF_C3C7563447A8__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "EdGameObject.h"

namespace MechWarrior4
{
class Objective; 
};
class EdObjective;
using namespace MechWarrior4;

class EdObjective : public EdGameObject  
{
private:
protected:
	void Copy(EdObjective &obj);
	Objective *GetObjective();
public:
	EdGUIObject *Clone();
	CString GetDescriptionText(); 
	CString GetNeutralText();	
	CString GetFailText();		
	CString GetSuccessText();	
	
	void SetDescriptionText(CString &text); 
	void SetNeutralText(CString &text);	
	void SetFailText(CString &text);		
	void SetSuccessText(CString &text);	

	bool GetVisible();
	bool GetHelpMessage();
	bool GetPrimary();
	int GetComLevel();

	void SetVisible(bool flag);
	void SetHelpMessage(bool flag);
	void SetPrimary(bool flag);
	void SetComLevel(int clevel);


	EdObjective();
	EdObjective(CString name);
	virtual ~EdObjective();

};

#endif // !defined(AFX_EDOBJECTIVE_H__ED62766D_CF98_40E3_8DAF_C3C7563447A8__INCLUDED_)
